aboutsummaryrefslogtreecommitdiffstats
path: root/pkg/host/features.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/host/features.go')
-rw-r--r--pkg/host/features.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkg/host/features.go b/pkg/host/features.go
index 8b78637fb..14d4f5c89 100644
--- a/pkg/host/features.go
+++ b/pkg/host/features.go
@@ -102,7 +102,7 @@ func Setup(target *prog.Target, features *Features, featureFlags csource.Feature
if features[FeatureFault].Enabled {
args = append(args, "fault")
}
- if target.OS == "linux" && featureFlags["binfmt_misc"].Enabled {
+ if target.OS == targets.Linux && featureFlags["binfmt_misc"].Enabled {
args = append(args, "binfmt_misc")
}
if features[FeatureKCSAN].Enabled {
@@ -117,6 +117,6 @@ func Setup(target *prog.Target, features *Features, featureFlags csource.Feature
func noHostChecks(target *prog.Target) bool {
// HostFuzzer targets can't run Go binaries on the targets,
- // so we actually run on the host on another OS. The same for "test" OS.
- return targets.Get(target.OS, target.Arch).HostFuzzer || target.OS == "test"
+ // so we actually run on the host on another OS. The same for targets.TestOS OS.
+ return targets.Get(target.OS, target.Arch).HostFuzzer || target.OS == targets.TestOS
}